.. SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
..
.. SPDX-License-Identifier: MPL-2.0

.. _intro:

===========================
Intro to Energy Forecasting
===========================

.. admonition:: Needs revision

    This page is inherited from OpenSTEF 3.0 and may still be revised. ...

.. include:: methodology_train_predict.rst
